`timescale 1ps / 1ps
module gazou_gen_c (
  clk,
  rstb,
  tmg_da_en,
  v_c,
  h_c,
  gen_da_en,
  gen_da_r,
  gen_da_g,
  gen_da_b,
  led_row_0,
  led_row_1,
  led_row_2,
  led_row_3,
  led_row_4,
  led_row_5,
  led_row_6,
  led_row_7
);

  input clk;
  input rstb;
  input tmg_da_en;
  input [9:0] v_c;
  input [9:0] h_c;
  output gen_da_en;
  output [7:0]gen_da_r;
  output [7:0]gen_da_g;
  output [7:0]gen_da_b;
  output [7:0] led_row_0;
  output [7:0] led_row_1;
  output [7:0] led_row_2;
  output [7:0] led_row_3;
  output [7:0] led_row_4;
  output [7:0] led_row_5;
  output [7:0] led_row_6;
  output [7:0] led_row_7;

  reg gen_da_en;
  reg [7:0]gen_da_r;
  reg [7:0]gen_da_g;
  reg [7:0]gen_da_b;
  reg [7:0] bv_c;
  reg [7:0] bh_c;

  //led map
   reg [ 6:0] rom_adr;
   wire [7:0] rom_da;
   wire       led_map_chg;
   
 
  reg [25:0]  map_chg_cnt;
  reg [7:0] led_row_0;
  reg [7:0] led_row_1;
  reg [7:0] led_row_2;
  reg [7:0] led_row_3;
  reg [7:0] led_row_4;
  reg [7:0] led_row_5;
  reg [7:0] led_row_6;
  reg [7:0] led_row_7;
  wire [2:0] led_col_no;
    
   parameter  size_4 = 32;
   parameter  led_r0_v = 320;
   parameter  led_r1_v = led_r0_v + size_4;
   parameter  led_r2_v = led_r1_v + size_4;
   parameter  led_r3_v = led_r2_v + size_4;
   parameter  led_r4_v = led_r3_v + size_4;
   parameter  led_r5_v = led_r4_v + size_4;
   parameter  led_r6_v = led_r5_v + size_4;
   parameter  led_r7_v = led_r6_v + size_4;
   parameter  led_v_end = led_r7_v + size_4;
   parameter  led_h = 512;
   parameter  led_h_end = led_h + size_4*8 ;  
   
    
assign led_col_no = 3'd7 - h_c[7:5];
   
always @ (posedge clk or negedge rstb )
if (rstb==1'b0) 
  begin
    gen_da_r <= 8'd0;
    gen_da_g <= 8'd0;
    gen_da_b <= 8'd0;
    gen_da_en <= 1'b0;
  end
else
    begin
      gen_da_en <= 1'b0 ;
      gen_da_r <= 8'd0;
      gen_da_g <= 8'd0;
      gen_da_b <= 8'd0;
      // led_map
      if ((h_c>=led_h)&&(h_c<led_h_end))
        begin
          if ((v_c>=led_r0_v)&&(v_c< led_v_end))
          begin
            gen_da_en <= 1'b1;
            gen_da_r<=8'hff;
            //row_0
            if ((v_c>=led_r0_v)&&(v_c<led_r1_v)) 
              if (led_row_0[led_col_no]==1'b1)
                begin
                  gen_da_g<=8'h0;
                  gen_da_b<=8'h0;
                end            
              else
                begin
                  gen_da_g<=8'hff;
                  gen_da_b<=8'hff;
                end         
            //row_1   
            if ((v_c>=led_r1_v)&&(v_c<led_r2_v))
              if (led_row_1[led_col_no]==1'b1)
                begin
                  gen_da_g<=8'h0;
                  gen_da_b<=8'h0;
                end            
              else
                begin
                  gen_da_g<=8'hff;
                  gen_da_b<=8'hff;
                end     
            //row_2
            if ((v_c>=led_r2_v)&&(v_c<led_r3_v)) 
              if (led_row_2[led_col_no]==1'b1)
                begin
                  gen_da_g<=8'h0;
                  gen_da_b<=8'h0;
                end            
              else
                begin
                  gen_da_g<=8'hff;
                  gen_da_b<=8'hff;
                end                    
            //row_3
            if ((v_c>=led_r3_v)&&(v_c<led_r4_v)) 
              if (led_row_3[led_col_no]==1'b1)
                begin
                  gen_da_g<=8'h0;
                  gen_da_b<=8'h0;
                end            
              else
                begin
                  gen_da_g<=8'hff;
                  gen_da_b<=8'hff;
              end         
            //row_4   
            if ((v_c>=led_r4_v)&&(v_c<led_r5_v))
              if (led_row_4[led_col_no]==1'b1)
                begin
                  gen_da_g<=8'h0;
                  gen_da_b<=8'h0;
                end            
              else
                begin
                  gen_da_g<=8'hff;
                  gen_da_b<=8'hff;
                end              
            //row_5
            if ((v_c>=led_r5_v)&&(v_c<led_r6_v)) 
              if (led_row_5[led_col_no]==1'b1)
                begin
                  gen_da_g<=8'h0;
                  gen_da_b<=8'h0;
                end            
              else
                begin
                  gen_da_g<=8'hff;
                  gen_da_b<=8'hff;
              end                    
            //row_6
            if ((v_c>=led_r6_v)&&(v_c<led_r7_v)) 
              if (led_row_6[led_col_no]==1'b1)
                begin
                  gen_da_g<=8'h0;
                  gen_da_b<=8'h0;
                end            
              else
                begin
                  gen_da_g<=8'hff;
                  gen_da_b<=8'hff;
                end         
            //row_7
            if ((v_c>=led_r7_v)&&(v_c<led_v_end))
              if (led_row_7[led_col_no]==1'b1)
                begin
                  gen_da_g<=8'h0;
                  gen_da_b<=8'h0;
                end            
              else
                begin
                  gen_da_g<=8'hff;
                  gen_da_b<=8'hff;
                end
            end
          end            
    end

 

//led map

led_data_rom led_data_rom (
        .a( rom_adr), // Bus [3 : 0] 
        .spo(rom_da)); // Bus [7 : 0] 
   
always @ (posedge clk or negedge rstb )
if (rstb==1'b0)
  map_chg_cnt <= 26'd0;
else
  map_chg_cnt <= map_chg_cnt + 26'd1;

assign led_map_chg = (map_chg_cnt[22:0]==24'h7fffff)?1'b1:1'b0;
//assign led_map_chg = (map_chg_cnt[7:0]==4'hff)?1'b1:1'b0;
   

always @ (posedge clk or negedge rstb )
 if (rstb==1'b0)
   begin
      rom_adr <= 7'd0;
   end
else
  if(led_map_chg==1'b1)
    rom_adr <=  rom_adr+ 4'd1;
  else
    rom_adr <=  rom_adr ;
   
always @ (posedge clk or negedge rstb )
if (rstb==1'b0) 
  begin
     led_row_0 <= 8'b00000000;
     led_row_1 <= 8'b00000000;
     led_row_2 <= 8'b00000000;
     led_row_3 <= 8'b00000000;
     led_row_4 <= 8'b00000000;
     led_row_5 <= 8'b00000000;
     led_row_6 <= 8'b00000000;
     led_row_7 <= 8'b00000000;
     /*
     led_row_0 <= 8'b11111111;
     led_row_1 <= 8'b11111111;
     led_row_2 <= 8'b11111111;
     led_row_3 <= 8'b11111111;
     led_row_4 <= 8'b11111111;
     led_row_5 <= 8'b11111111;
     led_row_6 <= 8'b11111111;
     led_row_7 <= 8'b11111111;
     */
     /*
     led_row_0 <= 8'b11001100;
     led_row_1 <= 8'b10011001;
     led_row_2 <= 8'b00110011;
     led_row_3 <= 8'b01100110;
     led_row_4 <= 8'b11001100;
     led_row_5 <= 8'b10011001;
     led_row_6 <= 8'b00110011;
      led_row_7 <= 8'b01100110;
     */
     /*
     led_row_0 <= 8'b10001000;
     led_row_1 <= 8'b01000100;
     led_row_2 <= 8'b00100010;
     led_row_3 <= 8'b00010001;
     led_row_4 <= 8'b11101110;
     led_row_5 <= 8'b11011101;
     led_row_6 <= 8'b10111011;
     led_row_7 <= 8'b01110111;
     */
  end
else
  if(led_map_chg==1'b1)
    begin
       led_row_0 <= {led_row_0[6:0],rom_da[0]};
       led_row_1 <= {led_row_1[6:0],rom_da[1]};
       led_row_2 <= {led_row_2[6:0],rom_da[2]};
       led_row_3 <= {led_row_3[6:0],rom_da[3]};
       led_row_4 <= {led_row_4[6:0],rom_da[4]};
       led_row_5 <= {led_row_5[6:0],rom_da[5]};
       led_row_6 <= {led_row_6[6:0],rom_da[6]};
       led_row_7 <= {led_row_7[6:0],rom_da[7]};
    end // if (dis_cnt[7:0]==8'hff)
  else
    begin
       led_row_0 <= led_row_0;
       led_row_1 <= led_row_1;
       led_row_2 <= led_row_2;
       led_row_3 <= led_row_3;
       led_row_4 <= led_row_4;
       led_row_5 <= led_row_5;
       led_row_6 <= led_row_6;
       led_row_7 <= led_row_7;       
    end

   
endmodule








